@@ -19,18 +19,9 @@ try:
     import h5pyd
 except ImportError:
     no_h5pyd = True
-    h5_group_types = (h5py.Group,)
-    h5_dataset_types = (h5py.Dataset,)
 else:
     no_h5pyd = False
-    h5_group_types = (h5py.Group, h5pyd.Group)
-    h5_dataset_types = (h5py.Dataset, h5pyd.Dataset)
 
-_NC_PROPERTIES = "version=2,h5netcdf=%s,hdf5=%s,h5py=%s" % (
-    __version__,
-    h5py.version.hdf5_version,
-    h5py.__version__,
-)
 
 NOT_A_VARIABLE = b"This is a netCDF dimension but not a netCDF variable."
 
@@ -292,7 +283,7 @@ class BaseVariable(object):
             key = _transform_1d_boolean_indexers(key)
 
         if getattr(self._root, "decode_vlen_strings", False):
-            string_info = h5py.check_string_dtype(self._h5ds.dtype)
+            string_info = self._root._h5py.check_string_dtype(self._h5ds.dtype)
             if string_info and string_info.length is None:
                 return self._h5ds.asstr()[key]
 
@@ -325,7 +316,9 @@ class BaseVariable(object):
     @property
     def attrs(self):
         """Return variable attributes."""
-        return Attributes(self._h5ds.attrs, self._root._check_valid_netcdf_dtype)
+        return Attributes(
+            self._h5ds.attrs, self._root._check_valid_netcdf_dtype, self._root._h5py
+        )
 
     _cls_name = "h5netcdf.Variable"
 
@@ -454,7 +447,7 @@ class Group(Mapping):
             phony_dims = Counter()
 
         for k, v in self._h5group.items():
-            if isinstance(v, h5_group_types):
+            if isinstance(v, self._root._h5py.Group):
                 # add to the groups collection if this is a h5py(d) Group
                 # instance
                 self._groups.add(k)
@@ -471,7 +464,7 @@ class Group(Mapping):
                             phony_dims |= Counter(v.shape)
 
                 if not _netcdf_dimension_but_not_variable(v):
-                    if isinstance(v, h5_dataset_types):
+                    if isinstance(v, self._root._h5py.Dataset):
                         self._variables.add(k)
 
         # iterate over found phony dimensions and create them
@@ -508,6 +501,8 @@ class Group(Mapping):
 
     @property
     def _track_order(self):
+        if self._root._h5py.__name__ == "h5pyd":
+            return False
         # TODO: make a suggestion to upstream to create a property
         # for files to get if they track the order
         # As of version 3.6.0 this property did not exist
@@ -548,7 +543,11 @@ class Group(Mapping):
     def _create_child_group(self, name):
         if name in self:
             raise ValueError("unable to create group %r (name already exists)" % name)
-        self._h5group.create_group(name, track_order=self._track_order)
+        kwargs = {}
+        if self._root._h5py.__name__ == "h5py":
+            kwargs.update(track_order=self._track_order)
+
+        self._h5group.create_group(name, **kwargs)
         self._groups[name] = self._group_cls(self, name)
         return self._groups[name]
 
@@ -590,7 +589,6 @@ class Group(Mapping):
             raise ValueError(
                 "unable to create variable %r " "(name already exists)" % name
             )
-
         if data is not None:
             data = np.asarray(data)
 
@@ -647,19 +645,13 @@ class Group(Mapping):
         if shape != maxshape:
             kwargs["maxshape"] = maxshape
 
-        warn_h5py_chunking = False
         has_unsized_dims = 0 in shape
         if has_unsized_dims and chunks in {None, True}:
-            # TODO: set default to "h5netcdf" in h5netcdf>=1.0, and remove warning
-            if chunking_heuristic is None:
-                warn_h5py_chunking = True
-                chunking_heuristic = "h5py"
-
-            if chunking_heuristic == "h5py":
+            if chunking_heuristic in [None, "h5netcdf"]:
+                chunks = _get_default_chunksizes(shape, dtype)
+            elif chunking_heuristic == "h5py":
                 # do nothing -> h5py will handle chunks internally
                 pass
-            elif chunking_heuristic == "h5netcdf":
-                chunks = _get_default_chunksizes(shape, dtype)
             else:
                 raise ValueError(
                     "got unrecognized value %s for chunking_heuristic argument "
@@ -675,30 +667,20 @@ class Group(Mapping):
             self._dimensions[name]._detach_scale()
             del self._h5group[name]
 
+        if self._root._h5py.__name__ == "h5py":
+            kwargs.update(dict(track_order=self._parent._track_order))
+
         # create hdf5 variable
-        h5ds = self._h5group.create_dataset(
+        self._h5group.create_dataset(
             h5name,
             shape,
             dtype=dtype,
             data=data,
             chunks=chunks,
             fillvalue=fillvalue,
-            track_order=self._track_order,
             **kwargs,
         )
 
-        if warn_h5py_chunking:
-            h5netcdf_chunks = _get_default_chunksizes(shape, dtype)
-            warnings.warn(
-                "Using h5py's default chunking with unlimited dimensions can lead "
-                "to increased file sizes and degraded performance (using chunks: %r). "
-                'Consider passing ``chunking_heuristic="h5netcdf"`` (would give chunks: %r; '
-                "default in h5netcdf >= 1.0), or set chunk sizes explicitly. "
-                'To silence this warning, pass ``chunking_heuristic="h5py"``. '
-                % (h5ds.chunks, h5netcdf_chunks),
-                FutureWarning,
-            )
-
         # create variable class instance
         variable = self._variable_cls(self, h5name, dimensions)
         self._variables[h5name] = variable
@@ -757,8 +739,9 @@ class Group(Mapping):
         chunks : tuple, optional
             Tuple of integers specifying the chunksizes of each variable dimension.
         chunking_heuristic : str, optional
-            Specify auto-chunking approach. Can be either of ``h5py`` or ``h5netcdf``.
-            Discussion on ``h5netcdf`` chunking can be found in (:issue:`52`) and (:pull:`127`).
+            Specify auto-chunking approach. Can be either of ``h5py`` or ``h5netcdf``. Defaults to
+            ``h5netcdf``. Discussion on ``h5netcdf`` chunking can be found in (:issue:`52`)
+            and (:pull:`127`).
         compression : str, optional
             Compression filter to apply, defaults to ``gzip``
         compression_opts : int
@@ -858,7 +841,9 @@ class Group(Mapping):
 
     @property
     def attrs(self):
-        return Attributes(self._h5group.attrs, self._root._check_valid_netcdf_dtype)
+        return Attributes(
+            self._h5group.attrs, self._root._check_valid_netcdf_dtype, self._root._h5py
+        )
 
     _cls_name = "h5netcdf.Group"
 
@@ -902,9 +887,7 @@ class Group(Mapping):
 
 
 class File(Group):
-    def __init__(
-        self, path, mode=None, invalid_netcdf=False, phony_dims=None, **kwargs
-    ):
+    def __init__(self, path, mode="r", invalid_netcdf=False, phony_dims=None, **kwargs):
         """NetCDF4 file constructor.
 
         Parameters
@@ -913,7 +896,7 @@ class File(Group):
             Location of the netCDF4 file to be accessed.
 
         mode: "r", "r+", "a", "w"
-            A valid file access mode.
+            A valid file access mode. Defaults to "r".
 
         invalid_netcdf: bool
             Allow writing netCDF4 with data types and attributes that would
@@ -959,18 +942,6 @@ class File(Group):
         #         "for more details."
         #     )
 
-        # Deprecating mode='a' in favor of mode='r'
-        # If mode is None default to 'a' and issue a warning
-        if mode is None:
-            msg = (
-                "Falling back to mode='a'. "
-                "In future versions, mode will default to read-only. "
-                "It is recommended to explicitly set mode='r' to prevent any unintended "
-                "changes to the file."
-            )
-            warnings.warn(msg, FutureWarning, stacklevel=2)
-            mode = "a"
-
         if version.parse(h5py.__version__) >= version.parse("3.0.0"):
             self.decode_vlen_strings = kwargs.pop("decode_vlen_strings", None)
         try:
@@ -982,17 +953,19 @@ class File(Group):
                             "opening urls: {}".format(path)
                         )
                     try:
-                        with h5pyd.File(path, "r") as f:  # noqa
+                        with h5pyd.File(path, "r", **kwargs) as f:  # noqa
                             pass
                         self._preexisting_file = True
                     except IOError:
                         self._preexisting_file = False
-                    self._h5file = h5pyd.File(
+                    self._h5py = h5pyd
+                    self._h5file = self._h5py.File(
                         path, mode, track_order=track_order, **kwargs
                     )
                 else:
                     self._preexisting_file = os.path.exists(path) and mode != "w"
-                    self._h5file = h5py.File(
+                    self._h5py = h5py
+                    self._h5file = self._h5py.File(
                         path, mode, track_order=track_order, **kwargs
                     )
             else:  # file-like object
@@ -1003,7 +976,8 @@ class File(Group):
                     )
                 else:
                     self._preexisting_file = mode in {"r", "r+", "a"}
-                    self._h5file = h5py.File(
+                    self._h5py = h5py
+                    self._h5file = self._h5py.File(
                         path, mode, track_order=track_order, **kwargs
                     )
         except Exception:
@@ -1042,20 +1016,7 @@ class File(Group):
                 self.decode_vlen_strings = True
             else:
                 if self.decode_vlen_strings is None:
-                    msg = (
-                        "String decoding changed with h5py >= 3.0. "
-                        "See https://docs.h5py.org/en/latest/strings.html and "
-                        "https://github.com/h5netcdf/h5netcdf/issues/132 for more details. "
-                        "Currently backwards compatibility with h5py < 3.0 is kept by "
-                        "decoding vlen strings per default. This will change in future "
-                        "versions for consistency with h5py >= 3.0. To silence this "
-                        "warning set kwarg ``decode_vlen_strings=False`` which will "
-                        "return Python bytes from variables containing vlen strings. Setting "
-                        "``decode_vlen_strings=True`` forces vlen string decoding which returns "
-                        "Python strings from variables containing vlen strings."
-                    )
-                    warnings.warn(msg, FutureWarning, stacklevel=2)
-                    self.decode_vlen_strings = True
+                    self.decode_vlen_strings = False
 
         self._max_dim_id = -1
         # This maps keeps track of all HDF5 datasets corresponding to this group.
@@ -1121,15 +1082,40 @@ class File(Group):
     def parent(self):
         return None
 
+    @property
+    def _root(self):
+        return self
+
     def flush(self):
         if self._writable:
+            # only write `_NCProperties` in newly created files
             if not self._preexisting_file and not self.invalid_netcdf:
+                _NC_PROPERTIES = "version=2,h5netcdf=%s,hdf5=%s,%s=%s" % (
+                    __version__,
+                    self._h5py.version.hdf5_version,
+                    self._h5py.__name__,
+                    self._h5py.__version__,
+                )
                 self.attrs._h5attrs["_NCProperties"] = np.array(
                     _NC_PROPERTIES,
                     dtype=h5py.string_dtype(
                         encoding="ascii", length=len(_NC_PROPERTIES)
                     ),
                 )
+            if self.invalid_netcdf:
+                # see https://github.com/h5netcdf/h5netcdf/issues/165
+                # warn user if .nc file extension is used for invalid netcdf features
+                if os.path.splitext(self.filename)[1] == ".nc":
+                    msg = (
+                        f"You are writing invalid netcdf features to file "
+                        f"`{self.filename}`. The file will thus be not conforming "
+                        f"to NetCDF-4 standard and might not be readable by other "
+                        f"netcdf tools. Consider using a different extension."
+                    )
+                    warnings.warn(msg, UserWarning, stacklevel=2)
+                # remove _NCProperties if invalid_netcdf if exists
+                if "_NCProperties" in self.attrs._h5attrs:
+                    del self.attrs._h5attrs["_NCProperties"]
 
     sync = flush
 
