@@ -28,29 +28,24 @@ except ImportError:
 remote_h5 = ("http:", "hdf5:")
 
 
-@pytest.fixture()
-def restapi(pytestconfig):
-    return pytestconfig.getoption("restapi")
-
-
 @pytest.fixture
 def tmp_local_netcdf(tmpdir):
     return str(tmpdir.join("testfile.nc"))
 
 
 @pytest.fixture(params=["testfile.nc", "hdf5://testfile"])
-def tmp_local_or_remote_netcdf(request, tmpdir, restapi):
+def tmp_local_or_remote_netcdf(request, tmpdir, hsds_up):
     if request.param.startswith(remote_h5):
-        if not restapi:
-            pytest.skip("Do not test with HDF5 REST API")
-        elif without_h5pyd:
+        if without_h5pyd:
             pytest.skip("h5pyd package not available")
-        if any([env.get(v) is None for v in ("HS_USERNAME", "HS_PASSWORD")]):
-            pytest.skip("HSDS username and/or password missing")
+        elif not hsds_up:
+            pytest.skip("HSDS service not running")
         rnd = "".join(random.choice(string.ascii_uppercase) for _ in range(5))
         return (
-            env["HS_ENDPOINT"]
-            + env["H5PYD_TEST_FOLDER"]
+            "hdf5://"
+            + "home"
+            + "/"
+            + env["HS_USERNAME"]
             + "/"
             + "testfile"
             + rnd
@@ -187,8 +182,10 @@ def write_h5netcdf(tmp_netcdf):
     v[...] = 1
     v.attrs["units"] = "meters"
 
-    v = ds.create_variable("y", ("y",), int, fillvalue=-1)
-    v[:4] = np.arange(4)
+    remote_file = isinstance(tmp_netcdf, str) and tmp_netcdf.startswith(remote_h5)
+    if not remote_file:
+        v = ds.create_variable("y", ("y",), int, fillvalue=-1)
+        v[:4] = np.arange(4)
 
     v = ds.create_variable("z", ("z", "string3"), data=_char_array, fillvalue=b"X")
 
@@ -247,6 +244,7 @@ def read_legacy_netcdf(tmp_netcdf, read_module, write_module):
             "foo_unlimited",
         ]
     )
+
     assert set(ds.groups) == set(["subgroup"])
     assert ds.parent is None
     v = ds.variables["foo"]
@@ -340,10 +338,9 @@ def read_h5netcdf(tmp_netcdf, write_module, decode_vlen_strings):
     assert set(ds.dimensions) == set(
         ["x", "y", "z", "empty", "string3", "mismatched_dim", "unlimited"]
     )
-    assert set(ds.variables) == set(
+    variables = set(
         [
             "foo",
-            "y",
             "z",
             "intscalar",
             "scalar",
@@ -352,6 +349,11 @@ def read_h5netcdf(tmp_netcdf, write_module, decode_vlen_strings):
             "foo_unlimited",
         ]
     )
+    # fix current failure of hsds/h5pyd
+    if not remote_file:
+        variables |= set(["y"])
+    assert set(ds.variables) == variables
+
     assert set(ds.groups) == set(["subgroup"])
     assert ds.parent is None
 
@@ -370,19 +372,21 @@ def read_h5netcdf(tmp_netcdf, write_module, decode_vlen_strings):
     assert not v.fletcher32
     assert v.shuffle
 
-    v = ds["y"]
-    assert array_equal(v, np.r_[np.arange(4), [-1]])
-    assert v.dtype == int
-    assert v.dimensions == ("y",)
-    assert v.ndim == 1
-    assert list(v.attrs) == ["_FillValue"]
-    assert v.attrs["_FillValue"] == -1
+    # fix current failure of hsds/h5pyd
     if not remote_file:
-        assert v.chunks is None
-    assert v.compression is None
-    assert v.compression_opts is None
-    assert not v.fletcher32
-    assert not v.shuffle
+        v = ds["y"]
+        assert array_equal(v, np.r_[np.arange(4), [-1]])
+        assert v.dtype == int
+        assert v.dimensions == ("y",)
+        assert v.ndim == 1
+        assert list(v.attrs) == ["_FillValue"]
+        assert v.attrs["_FillValue"] == -1
+        if not remote_file:
+            assert v.chunks is None
+        assert v.compression is None
+        assert v.compression_opts is None
+        assert not v.fletcher32
+        assert not v.shuffle
     ds.close()
 
     if is_h5py_char_working(tmp_netcdf, "z"):
@@ -528,9 +532,10 @@ def test_repr(tmp_local_or_remote_netcdf):
 
 
 def test_attrs_api(tmp_local_or_remote_netcdf):
+    h5 = get_hdf5_module(tmp_local_or_remote_netcdf)
     with h5netcdf.File(tmp_local_or_remote_netcdf, "w") as ds:
         ds.attrs["conventions"] = "CF"
-        ds.attrs["empty_string"] = h5py.Empty(dtype=np.dtype("|S1"))
+        ds.attrs["empty_string"] = h5.Empty(dtype=np.dtype("|S1"))
         ds.dimensions["x"] = 1
         v = ds.create_variable("x", ("x",), "i4")
         v.attrs.update({"units": "meters", "foo": "bar"})
@@ -584,17 +589,6 @@ def test_error_handling(tmp_local_or_remote_netcdf):
             ds.create_group("subgroup")
 
 
-@pytest.mark.skipif(
-    version.parse(h5py.__version__) < version.parse("3.0.0"),
-    reason="not needed with h5py < 3.0",
-)
-def test_decode_string_warning(tmp_local_or_remote_netcdf):
-    write_h5netcdf(tmp_local_or_remote_netcdf)
-    with pytest.warns(FutureWarning):
-        with h5netcdf.File(tmp_local_or_remote_netcdf, "r") as ds:
-            assert ds.name == "/"
-
-
 @pytest.mark.skipif(
     version.parse(h5py.__version__) < version.parse("3.0.0"),
     reason="not needed with h5py < 3.0",
@@ -608,19 +602,6 @@ def test_decode_string_error(tmp_local_or_remote_netcdf):
             assert ds.name == "/"
 
 
-def test_mode_warning(tmp_local_or_remote_netcdf):
-    with pytest.warns(FutureWarning):
-        with h5netcdf.File(tmp_local_or_remote_netcdf):
-            pass
-
-
-def test_unlimited_chunk_warning(tmp_local_or_remote_netcdf):
-    with pytest.warns(FutureWarning):
-        with h5netcdf.File(tmp_local_or_remote_netcdf, "w") as ds:
-            ds.dimensions = {"x": None}
-            ds.create_variable("foo", ("x",), float)
-
-
 def create_invalid_netcdf_data():
     foo_data = np.arange(125).reshape(5, 5, 5)
     bar_data = np.arange(625).reshape(25, 5, 5)
@@ -652,6 +633,8 @@ def check_invalid_netcdf4(var, i):
 
 
 def test_invalid_netcdf4(tmp_local_or_remote_netcdf):
+    if tmp_local_or_remote_netcdf.startswith(remote_h5):
+        pytest.skip("netCDF4 package does not work with remote HDF5 files")
     h5 = get_hdf5_module(tmp_local_or_remote_netcdf)
     with h5.File(tmp_local_or_remote_netcdf, "w") as f:
         var, var2 = create_invalid_netcdf_data()
@@ -673,10 +656,12 @@ def test_invalid_netcdf4(tmp_local_or_remote_netcdf):
             var = dsr[grp].variables
             check_invalid_netcdf4(var, i)
 
-    with netCDF4.Dataset(tmp_local_or_remote_netcdf, "r") as dsr:
-        for i, grp in enumerate(grps):
-            var = dsr[grp].variables
-            check_invalid_netcdf4(var, i)
+    if not tmp_local_or_remote_netcdf.startswith(remote_h5):
+        # netcdf4 package does not work with remote HDF5 files
+        with netCDF4.Dataset(tmp_local_or_remote_netcdf, "r") as dsr:
+            for i, grp in enumerate(grps):
+                var = dsr[grp].variables
+                check_invalid_netcdf4(var, i)
 
     with h5netcdf.File(tmp_local_or_remote_netcdf, "r") as ds:
         with raises(ValueError):
@@ -710,6 +695,8 @@ def check_invalid_netcdf4_mixed(var, i):
 
 
 def test_invalid_netcdf4_mixed(tmp_local_or_remote_netcdf):
+    if tmp_local_or_remote_netcdf.startswith(remote_h5):
+        pytest.skip("netCDF4 package does not work with remote HDF5 files")
     h5 = get_hdf5_module(tmp_local_or_remote_netcdf)
     with h5.File(tmp_local_or_remote_netcdf, "w") as f:
         var, var2 = create_invalid_netcdf_data()
@@ -738,9 +725,11 @@ def test_invalid_netcdf4_mixed(tmp_local_or_remote_netcdf):
         var = ds.variables
         check_invalid_netcdf4_mixed(var, 0)
 
-    with netCDF4.Dataset(tmp_local_or_remote_netcdf, "r") as ds:
-        var = ds.variables
-        check_invalid_netcdf4_mixed(var, 3)
+    if not tmp_local_or_remote_netcdf.startswith(remote_h5):
+        # netcdf4 package does not work with remote HDF5 files
+        with netCDF4.Dataset(tmp_local_or_remote_netcdf, "r") as ds:
+            var = ds.variables
+            check_invalid_netcdf4_mixed(var, 3)
 
     with h5netcdf.File(tmp_local_or_remote_netcdf, "r") as ds:
         with raises(ValueError):
@@ -855,8 +844,8 @@ def test_failed_read_open_and_clean_delete(tmpdir):
 def test_create_variable_matching_saved_dimension(tmp_local_or_remote_netcdf):
     h5 = get_hdf5_module(tmp_local_or_remote_netcdf)
 
-    if h5 is not h5py:
-        pytest.xfail("https://github.com/h5netcdf/h5netcdf/issues/48")
+    # if h5 is not h5py:
+    #     pytest.xfail("https://github.com/h5netcdf/h5netcdf/issues/48")
 
     with h5netcdf.File(tmp_local_or_remote_netcdf, "w") as f:
         f.dimensions["x"] = 2
@@ -874,6 +863,8 @@ def test_create_variable_matching_saved_dimension(tmp_local_or_remote_netcdf):
 
 
 def test_invalid_netcdf_error(tmp_local_or_remote_netcdf):
+    if tmp_local_or_remote_netcdf.startswith(remote_h5):
+        pytest.skip("Remote HDF5 does not yet support LZF compression")
     with h5netcdf.File(tmp_local_or_remote_netcdf, "w", invalid_netcdf=False) as f:
         # valid
         f.create_variable(
@@ -891,13 +882,14 @@ def test_invalid_netcdf_error(tmp_local_or_remote_netcdf):
 def test_invalid_netcdf_okay(tmp_local_or_remote_netcdf):
     if tmp_local_or_remote_netcdf.startswith(remote_h5):
         pytest.skip("h5pyd does not support NumPy complex dtype yet")
-    with h5netcdf.File(tmp_local_or_remote_netcdf, "w", invalid_netcdf=True) as f:
-        f.create_variable(
-            "lzf_compressed", data=[1], dimensions=("x"), compression="lzf"
-        )
-        f.create_variable("complex", data=1j)
-        f.attrs["complex_attr"] = 1j
-        f.create_variable("scaleoffset", data=[1], dimensions=("x",), scaleoffset=0)
+    with pytest.warns(UserWarning, match="invalid netcdf features"):
+        with h5netcdf.File(tmp_local_or_remote_netcdf, "w", invalid_netcdf=True) as f:
+            f.create_variable(
+                "lzf_compressed", data=[1], dimensions=("x"), compression="lzf"
+            )
+            f.create_variable("complex", data=1j)
+            f.attrs["complex_attr"] = 1j
+            f.create_variable("scaleoffset", data=[1], dimensions=("x",), scaleoffset=0)
     with h5netcdf.File(tmp_local_or_remote_netcdf, "r") as f:
         np.testing.assert_equal(f["lzf_compressed"][:], [1])
         assert f["complex"][...] == 1j
@@ -908,6 +900,28 @@ def test_invalid_netcdf_okay(tmp_local_or_remote_netcdf):
         assert "_NCProperties" not in f.attrs
 
 
+def test_invalid_netcdf_overwrite_valid(tmp_local_netcdf):
+    # https://github.com/h5netcdf/h5netcdf/issues/165
+    with netCDF4.Dataset(tmp_local_netcdf, mode="w"):
+        pass
+    with pytest.warns(UserWarning):
+        with h5netcdf.File(tmp_local_netcdf, "a", invalid_netcdf=True) as f:
+            f.create_variable(
+                "lzf_compressed", data=[1], dimensions=("x"), compression="lzf"
+            )
+            f.create_variable("complex", data=1j)
+            f.attrs["complex_attr"] = 1j
+            f.create_variable("scaleoffset", data=[1], dimensions=("x",), scaleoffset=0)
+    with h5netcdf.File(tmp_local_netcdf, "r") as f:
+        np.testing.assert_equal(f["lzf_compressed"][:], [1])
+        assert f["complex"][...] == 1j
+        assert f.attrs["complex_attr"] == 1j
+        np.testing.assert_equal(f["scaleoffset"][:], [1])
+    h5 = get_hdf5_module(tmp_local_netcdf)
+    with h5.File(tmp_local_netcdf, "r") as f:
+        assert "_NCProperties" not in f.attrs
+
+
 def test_reopen_file_different_dimension_sizes(tmp_local_netcdf):
     # regression test for https://github.com/h5netcdf/h5netcdf/issues/55
     with h5netcdf.File(tmp_local_netcdf, "w") as f:
@@ -919,8 +933,9 @@ def test_reopen_file_different_dimension_sizes(tmp_local_netcdf):
 
 
 def test_invalid_then_valid_no_ncproperties(tmp_local_or_remote_netcdf):
-    with h5netcdf.File(tmp_local_or_remote_netcdf, "w", invalid_netcdf=True):
-        pass
+    with pytest.warns(UserWarning, match="invalid netcdf features"):
+        with h5netcdf.File(tmp_local_or_remote_netcdf, "w", invalid_netcdf=True):
+            pass
     with h5netcdf.File(tmp_local_or_remote_netcdf, "a"):
         pass
     h5 = get_hdf5_module(tmp_local_or_remote_netcdf)
@@ -1686,7 +1701,7 @@ def test_bool_slicing_length_one_dim(tmp_local_netcdf):
             ds["hello"][bool_slice, :]
 
 
-def test_default_chunking(tmp_local_netcdf):
+def test_h5py_chunking(tmp_local_netcdf):
     with h5netcdf.File(tmp_local_netcdf, "w") as ds:
         ds.dimensions = {"x": 10, "y": 10, "z": 10, "t": None}
 
@@ -1695,11 +1710,6 @@ def test_default_chunking(tmp_local_netcdf):
         )
         chunks_h5py = v.chunks
 
-        v = ds.create_variable(
-            "hello2", ("x", "y", "z", "t"), "float", chunking_heuristic=None
-        )
-        chunks_default = v.chunks
-
         ds.resize_dimension("t", 4)
         v = ds.create_variable(
             "hello3", ("x", "y", "z", "t"), "float", chunking_heuristic="h5py"
@@ -1732,7 +1742,6 @@ def test_default_chunking(tmp_local_netcdf):
         chunks_true_resized = v.chunks
 
     assert chunks_h5py == chunks_true
-    assert chunks_default == chunks_true
     assert chunks_resized == chunks_true_resized
 
 
